@@ -79,12 +79,6 @@ def execute_command3(cmd):
     return status, output, lines
 
 
-# 如果subprocess.getstatusoutput出现乱码而失败，就使用这个方法执行命令
-def execute_command_use_os(cmd):
-    r = os.system(cmd)
-    return r
-
-
 # 执行shell命令,并返回结果
 def execute_command(cmd):
     major = sys.version_info[0]
@@ -378,36 +372,26 @@ def weixin_send_text(message, token=None, mobiles=[], is_at_all=False):
 
 
 def get_md5_code(arg, is_file=False):
-    """
-    :param is_file: 如果为True，就对文件做md5处理
-    :param arg: 原始字符串，或者文件路径
-    :return : 对原始字符串进行MD5加密的字符串
-    """
-    m = hashlib.md5()
-    if is_file:
-        img = open(arg, 'rb')
-        m.update(img.read())
-        img.close()
-    else:
-        b = arg.encode(encoding='utf-8')
-        m.update(b)
-    return m.hexdigest()
+    return md5(arg,is_file=is_file)
 
 
 def md5(arg, is_file=False):
     """
-    :param is_file: 如果为True，就对文件做md5处理
     :param arg: 原始字符串，或者文件路径
+    :param is_file: 如果为True，就对文件做md5处理
     :return : 对原始字符串进行MD5加密的字符串
     """
+    content = arg
     m = hashlib.md5()
+    temp_file = None
     if is_file:
-        img = open(arg, 'rb')
-        m.update(img.read())
-        img.close()
-    else:
-        b = arg.encode(encoding='utf-8')
-        m.update(b)
+        temp_file = open(arg, 'rb')
+        content = temp_file.read()
+    elif type(arg) is str:
+        content = arg.encode(encoding='utf-8')
+    m.update(content)
+    if temp_file is not None:
+        temp_file.close()
     return m.hexdigest()
 
 # def aes(text,apiSecret):
